package de.hwh.bsp.cookies;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class CookieServlet extends HttpServlet
{
    @Override
    protected void service(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException
    {
        Cookie oVornameCookie = null, oNachnameCookie = null;
        String sVorname, sNachname;
        
        // Zeichenkodierung auf UTF-8 setzen (für Formulardaten)
        request.setCharacterEncoding("UTF-8");
        
        // Cookies abrufen
        if (request.getCookies() != null)
        {
            for (Cookie oCookie : request.getCookies())
            {
                if (oCookie.getName().equals("vorname"))
                    oVornameCookie = oCookie;
                else if (oCookie.getName().equals("nachname"))
                    oNachnameCookie = oCookie;
            }
        }
        
        // Prüfen ob die Anfrage mittels der POST-Methode durchgeführt wurde
        if (request.getMethod() == "POST")
        {
            // Werte aus dem Formular abrufen
            sVorname = request.getParameter("vorname") != null ? request.getParameter("vorname") : "";
            sNachname = request.getParameter("nachname") != null ? request.getParameter("nachname") : "";
            
            // Cookies speichern, Werte darin speichern und diese der Antwort hinzufügen
            oVornameCookie = new Cookie("vorname", sVorname);
            oVornameCookie.setMaxAge(3600);
            response.addCookie(oVornameCookie);
            oNachnameCookie = new Cookie("nachname", sNachname);
            oNachnameCookie.setMaxAge(3600);
            response.addCookie(oNachnameCookie);
        }
        else
        {
            // Werte aus den Cookies abrufen
            sVorname = oVornameCookie != null ? oVornameCookie.getValue() : "";
            sNachname = oNachnameCookie != null ? oNachnameCookie.getValue() : "";
        }
        
        // Ausgabe als HTML-Seite
        response.setContentType("text/html;charset=UTF-8");
        
        // Ausgabe durchführen
        PrintWriter out = response.getWriter();
        out.println("<!DOCTYPE html>");
        out.println("<html>");
        out.println("    <head>");
        out.println("        <title>Cookies - Java EE Servlet Code-Beispiel</title>");
        out.println();
        out.println("        <meta charset=\"utf-8\" />");
        out.println();
        out.println("        <meta name=\"robots\" content=\"noindex,nofollow\" />");
        out.println("        <meta name=\"publisher\" content=\"Homepage-Webhilfe\" />");
        out.println("    </head>");
        out.println();
        out.println("    <body style=\"line-height: 1.5em;\">");
        out.println("        <form method=\"post\">");
        out.println("            Vorname: <input type=\"text\" name=\"vorname\" value=\"" + sVorname + "\" /><br />");
        out.println("            Nachname: <input type=\"text\" name=\"nachname\" value=\"" + sNachname + "\" /><br />");
        out.println("            <input type=\"submit\" value=\"Speichern\" />");
        out.println("        </form>");
        out.println("    </body>");
        out.println("</html>");
        out.close();
    }
}